# Tutorials
The tutorials use data that can be downloaded [here](https://drive.google.com/drive/folders/1dUBC1EbUgEH-Cug-oWIS7Yy_tpAqhe4j?usp=sharing).

## SPECT
Basic introduction:
* {doc}`notebooks/t_siminddata`
* {doc}`notebooks/t_dicomdata`

Reconstructing multiple bed positions:
* {doc}`notebooks/t_dicommultibed`

Estimating uncertainty in reconstruction
* {doc}`notebooks/t_uncertainty_spect`

Non-standard PSF modeling that accounts for septal penetration and scatter:
* {doc}`notebooks/t_ac225_simind_recon`
* {doc}`notebooks/t_ac225_dicom_recon`

## PET
* {doc}`notebooks/t_PETGATE_scat_sino`
* {doc}`notebooks/t_PETGATE_scat_sinoTOF`
* {doc}`notebooks/t_PETGATE_scat_lm`
* {doc}`notebooks/t_PETGATE_scat_lmTOF`
* {doc}`notebooks/t_PETGATE_DIP`
* {doc}`notebooks/t_GE_HDF5`

## CT
* {doc}`notebooks/t_CT_GEN3`

## Developer Guide
* {doc}`notebooks/t_examplesystemmatrix`
